Documentation
¶
Index ¶
Constants ¶
const ( // PSSHSoftwareVersion is the softwareversion field of RFC 4253 section 4.2. PSSHSoftwareVersion string = "PROTECTEDSSH0.1" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ExitMode ¶
type ExitMode int8
ExitMode is the mode for exiting. Only the explicit constants should be used.
const ( // ExitRude indicates that the daemon should exit as soon as it receives this notification. // Nothing should be expected to be logged and there should be no cleanup. ExitRude ExitMode = 1 // ExitErr is the same as ExitRude but should log the message for exiting. ExitErr ExitMode = -1 // ExitClean indicates that the daemon should exit cleanly when it's safe to do so. // Only the cleanup will be logged. ExitClean ExitMode = 2 // ExitWithReason is the same as ExitClean but should log the reason for exiting. ExitWithReason ExitMode = -2 )
type Message ¶
type Message string
Message is some message being sent to the daemon that should be logged.
Click to show internal directories.
Click to hide internal directories.